@@ -1,6 +1,25 @@
-
-#' @noRd
-#' @import data.table
+#' Downloads and formats CRU CL 2.0 data
+#'
+#' @param pre Logical. If TRUE, downloads precipitation data.
+#' @param pre_cv Logical. If TRUE, downloads precipitation data.
+#' @param rd0 Logical. If TRUE, downloads runoff data.
+#' @param tmp Logical. If TRUE, downloads temperature data.
+#' @param dtr Logical. If TRUE, downloads diurnal temperature range data.
+#' @param reh Logical. If TRUE, downloads relative humidity data.
+#' @param tmn Logical. If TRUE, downloads minimum temperature data.
+#' @param tmx Logical. If TRUE, downloads maximum temperature data.
+#' @param sunp Logical. If TRUE, downloads sunshine data.
+#' @param frs Logical. If TRUE, downloads frost day frequency data.
+#' @param wnd Logical. If TRUE, downloads wind speed data.
+#' @param elv Logical. If TRUE, downloads elevation data.
+#' @param cache_dir Character. Path to the cache directory.
+#'
+#' Handles the downloading of CRU CL 2.0 data. This function is called by
+#' [get_cru_df] and [get_cru_stack]. It is not intended to be called directly.
+#'
+#' @returns A data.table with the requested data.
+#'
+#' @dev
 .get_CRU <-
   function(pre,
            pre_cv,
@@ -25,16 +44,16 @@
     frs_file <- "grid_10min_frs.dat.gz"
     rd0_file <- "grid_10min_rd0.dat.gz"
 
-    # check if pre_cv or tmx/tmn (derived) are true, make sure proper ----------
+    # check if pre_cv or tmx/tmn (derived) are true, make sure proper ---------
     # parameters set TRUE
-    if (isTRUE(pre_cv)) {
+    if (pre_cv) {
       pre <- TRUE
     }
 
-    if (isTRUE(tmn) | isTRUE(tmx)) {
+    if (any(tmn, tmx)) {
       dtr <- tmp <- TRUE
     }
-    # create object list to filter downloads -----------------------------------
+    # create object list to filter downloads ----------------------------------
     object_list <- c(dtr, tmp, reh, elv, pre, sunp, wnd, frs, rd0)
 
     files <-
@@ -63,9 +82,9 @@
         "rd0_file"
       )
 
-    # filter downloaded --------------------------------------------------------
+    # filter downloaded -------------------------------------------------------
     # which files are being requested?
-    files <- files[object_list %in% !isTRUE(files)]
+    files <- files[which(object_list)]
 
     # which files are locally available?
     cache_dir_contents <-
@@ -74,9 +93,8 @@
     # which files requested need to be downloaded
     dl_files <- files[!(files %in% cache_dir_contents)]
 
-    # download files -----------------------------------------------------------
+    # download files ----------------------------------------------------------
     if (length(dl_files) > 0) {
-
       CRU_url <- "https://crudata.uea.ac.uk/cru/data/hrg/tmc/"
       dl_files <- as.list(paste0(CRU_url, dl_files))
 
@@ -90,8 +108,8 @@
         },
         error = function(x) {
           manage_cache$delete_all()
-          stop("\nThe file downloads have failed.\n
-               \nPlease start the download again.\n")
+          cli::cli_abort("The file downloads have failed.
+          Please start the download again.")
         }
       )
     }
@@ -99,7 +117,8 @@
     # filter files from cache directory in case there are local files for which
     # we do not want data
     cache_dir_contents <- as.list(list.files(cache_dir,
-                                             pattern = ".dat.gz$"))
+      pattern = ".dat.gz$"
+    ))
 
     files <- cache_dir_contents[cache_dir_contents %in% files]
 
@@ -110,4 +129,4 @@
     files <- gsub(" ", "\\ ", files, fixed = TRUE)
 
     return(files)
-    }
+  }
