@@ -1,4 +1,3 @@
-
 manage_cache <- NULL # nocov start
 
 .onLoad <-
@@ -9,7 +8,13 @@ manage_cache <- NULL # nocov start
       utils::globalVariables(c("."))
 
       x <- hoardr::hoard()
-      x$cache_path_set(path = "getCRUCLdata", type = "user_cache_dir")
+      x$cache_path_set(
+        path = "getCRUCLdata",
+        prefix = "org.R-project.R/R",
+        type = "user_cache_dir"
+      )
       manage_cache <<- x
     }
-  } # nocov end
+  }
+
+# nocov end
