@@ -1,30 +1,26 @@
-
-context("get_CRU_df")
-
 # Test that get_CRU_df fails if no parameters are TRUE -------------------------
 
 test_that("get_CRU_df fails if no parameters are TRUE", {
-  expect_error(get_CRU_df(),
-               "You must select at least one element for download.")
+  expect_error(
+    get_CRU_df(),
+    "You must select at least one element for download."
+  )
 })
 
-# Test that get_CRU_df will retrieve files from CRU FTP server
-test_that("get_CRU_df will retrieve files from CRU FTP server", {
-
-  skip_on_cran()
-
-  rm(CRU_tmp)
-  CRU_tmp <- get_CRU_df(tmp = TRUE, tmn = FALSE, tmx = FALSE, cache = FALSE)
-  expect_is(CRU_tmp, "tbl_df")
+# Test that get_CRU_df will retrieve files from CRU server
+test_that("get_CRU_df will retrieve files from CRU server", {
+  skip_if_offline()
+  CRU_tmp <- get_CRU_df(tmp = TRUE, cache = FALSE)
+  expect_type(CRU_tmp, "list")
 })
 
-# Test that get_CRU_df lists only .dat.gz files in the given dsn ------------
+# Test that get_CRU_df lists only .dat.gz files in the given dsn ---------------
 
 test_that("get_CRU_df lists only .dat.gz files in the given dsn", {
   # create files for testing, these data are the first 10 lines of pre and tmp
   # from the CRU CL v. 2.0 data
 
-  skip_on_cran()
+  skip_if_offline()
 
   unlink(list.files(
     path = tempdir(),
@@ -499,44 +495,42 @@ test_that("get_CRU_df lists only .dat.gz files in the given dsn", {
     list.files(tempdir(), pattern = ".dat.gz$", full.names = TRUE)
 
   expect_type(files, "character")
-  expect_equal(files, file.path(tempdir(), "grid_10min_tmp.dat.gz"))
+  expect_identical(files, file.path(tempdir(), "grid_10min_tmp.dat.gz"))
 })
 
 # Test that get_CRU_df sets the cache directory properly when cache is TRUE ----
 
 test_that("get_CRU_df sets the cache directory properly when cache is TRUE", {
-            skip_on_cran()
+  skip_if_offline()
 
-            cache <- TRUE
+  cache <- TRUE
 
-            if (isTRUE(cache)) {
-              cache_dir <- rappdirs::user_config_dir("getCRUCLdata")
-              if (!file.exists(cache_dir)) {
-                dir.create(cache_dir)
-              }
-            } else {
-              cache_dir <- tempdir()
-            }
+  if (cache) {
+    cache_dir <- rappdirs::user_config_dir("getCRUCLdata")
+    if (!file.exists(cache_dir)) {
+      dir.create(cache_dir)
+    }
+  } else {
+    cache_dir <- tempdir()
+  }
 
-            expect_equal(cache_dir, rappdirs::user_config_dir("getCRUCLdata"))
-
-          })
+  expect_identical(cache_dir, rappdirs::user_config_dir("getCRUCLdata"))
+})
 
 # Test that get_CRU_df sets the cache dir properly when cache is FALSE ---------
 
 test_that("get_CRU_df sets the cache directory properly when cache is FALSE", {
+  skip_if_offline()
+  cache <- FALSE
 
-            skip_on_cran()
-            cache <- FALSE
+  if (cache) {
+    cache_dir <- rappdirs::user_config_dir("getCRUCLdata")
+    if (!file.exists(cache_dir)) {
+      dir.create(cache_dir)
+    }
+  } else {
+    cache_dir <- tempdir()
+  }
 
-            if (isTRUE(cache)) {
-              cache_dir <- rappdirs::user_config_dir("getCRUCLdata")
-              if (!file.exists(cache_dir)) {
-                dir.create(cache_dir)
-              }
-            } else {
-              cache_dir <- tempdir()
-            }
-
-            expect_equal(cache_dir, tempdir())
-          })
+  expect_identical(cache_dir, tempdir())
+})
